@@ -33,18 +33,18 @@ class RddReport:
 
     ISSUE_TYPES = ['bug', 'requirement', 'theme', 'enhancement'] # non hierarchical tickets
     THEME = 'theme'
-    IGNORED_LABELS = {'wontfix', 'duplicate', 'invalid', 'I&T', 'untestable'}
-    NOT_TESTED = 'skip-i&t'
-    IGNORED_REPOS = {'PDS-Software-Issues-Repo', 'pds-template-repo-python', 'pdsen-corral', 'pdsen-operations',
-                     'roundup-action', 'github-actions-base', '.github', 'nasa-pds.github.io', 'pds-github-util',
-                     'pds-template-repo-java', 'devops-BROKEN', 'kdp'}
+    IGNORED_LABELS = {'wontfix', 'duplicate', 'invalid', 'I&T', 'untestable', 'task'}
+    SKIP_TESTING = 'skip-i&t'
+    IGNORED_REPOS = {'PDS-Software-Issues-Repo', 'pds-template-repo-python', 'pdsen-corral',
+                     'github-actions-base', '.github', 'nasa-pds.github.io', 'pds-github-util',
+                     'pds-template-repo-java', 'kdp', 'naif-pds4-bundler'}
     REPO_INFO = '*{}*\n\n' \
                 '.. list-table:: \n' \
                 '   :widths: 15 15 15 15 15 15\n\n' \
                 '   * - `User Guide <{}>`_\n' \
                 '     - `Github Repo <{}>`_\n' \
                 '     - `Issue Tracking <{}/issues>`_ \n' \
-                '     - `Backlog <{}/issues?q=is%3Aopen+is%3Aissue+label%3Abacklog>`_ \n' \
+                '     - `Requirements <{}/tree/main/docs/requirements>`_ \n' \
                 '     - `Stable Release <{}/releases/latest>`_ \n' \
                 '     - `Dev Release <{}/releases>`_ \n\n'
     SWG_REPO_NAME = 'pds-swg'
@@ -70,6 +70,7 @@ class RddReport:
         self._start_time = start_time
         self._end_time = end_time
         self._build = build
+        self._target_build = build.replace('-SNAPSHOT', '')
         self._rst_doc = RstClothReferenceable()
 
         self._rst_doc.title(title)
@@ -90,17 +91,21 @@ class RddReport:
         for t in RstRddReport.ISSUE_TYPES:
             issues[t] = []
 
-            if self._start_time:
-                self._logger.info("get %s issues from start time %s on ", t,  self._start_time)
-                type_issues = repo.issues(state=state, labels=t, direction='asc', start=self._start_time)
-            else:
-                labels = [t, self._build]
-                self._logger.info("get %s issues for build %s", t, self._build)
-                type_issues = repo.issues(state=state, labels=','.join(labels), direction='asc')
+            labels = [t]
+            if self._build:
+                labels.append(self._build)
+
+            self._logger.info("get %s issues for build %s", t, self._build)
+            type_issues = repo.issues(state=state, labels=','.join(labels), direction='asc')
 
             for issue in type_issues:
+                compare_date = issue.created_at
+                if state == 'closed':
+                    compare_date = issue.closed_at
+
                 if not ignore_issue(issue.labels(), ignore_labels=RstRddReport.IGNORED_LABELS) \
-                   and (self._end_time is None or issue.created_at < datetime.fromisoformat(self._end_time)):
+                   and (self._end_time is None or compare_date < datetime.fromisoformat(self._end_time))\
+                   and (self._start_time is None or compare_date > datetime.fromisoformat(self._start_time)):
                     issues[t].append(issue)
 
         return issues
@@ -134,7 +139,7 @@ class MetricsRddReport(RddReport):
         self.bugs_open_closed = {}
         self.bugs_severity = {}
 
-        self.high_and_critical_open_bugs = ""
+        self.open_bugs = {}
 
         self.epic_closed_for_the_build = {}
 
@@ -153,7 +158,9 @@ class MetricsRddReport(RddReport):
         print(self.bugs_severity)
 
         print('Open High/Critical Bugs')
-        print(self.high_and_critical_open_bugs)
+        for s,bugs in self.open_bugs.items():
+            print(s)
+            print(bugs)
 
         print('Closed Epics')
         print(self.epic_closed_for_the_build)
@@ -161,7 +168,7 @@ class MetricsRddReport(RddReport):
     def _non_bug_metrics(self, type, repo):
         for issue in repo.issues(
                 state='closed',
-                labels=type,
+                labels=f'{self._target_build},{type}',
                 direction='asc',
                 since=self._start_time
         ):
@@ -172,7 +179,7 @@ class MetricsRddReport(RddReport):
     def _bug_metrics(self, repo):
         for issue in repo.issues(
                 state='all',
-                labels='bug',
+                labels=f'{self._target_build},bug',
                 direction='asc',
                 since=self._start_time
         ):
@@ -195,9 +202,11 @@ class MetricsRddReport(RddReport):
                 else:
                     self.bugs_open_closed[issue.state] = 1
 
-                if issue.state == 'open' and severity in {'s.critical', 's.high'}:
+                if issue.state == 'open' and severity in {'s.critical', 's.high', 's.medium', 's.low'}:
                     self._logger.info("%s#%i %s %s %s", repo, issue.number, issue.title, severity, issue.state)
-                    self.high_and_critical_open_bugs += "%s#%i %s %s\n" % (repo, issue.number, issue.title, severity)
+                    if severity not in self.open_bugs:
+                        self.open_bugs[severity] = ""
+                    self.open_bugs[severity] += "%s#%i %s\n" % (repo, issue.number, issue.title)
 
 
                 # get count
@@ -208,7 +217,7 @@ class MetricsRddReport(RddReport):
 
     def _get_epics_count(self, repo):
 
-        epics = repo.issues(state='closed', labels=f'{self._build},Epic')
+        epics = repo.issues(state='closed', labels=f'{self._target_build},Epic')
         n = 0
 
         for _ in epics:
@@ -230,7 +239,7 @@ class MetricsRddReport(RddReport):
                 self._non_bug_metrics(t, repo)
 
     def add_repo(self, repo):
-        self._logger.info("add repo %s", repo)
+        self._logger.debug("add repo %s", repo)
         self._get_issue_type_count(repo)
 
 
@@ -240,15 +249,15 @@ class EpicFactory:
         self._logger = logger
 
     def create_enhancement(self, repo, gh_issue, build):
-        self._logger.info('Create enhancement for repo %s for issue %i', repo.name, gh_issue.number)
+        self._logger.debug('Create enhancement for repo %s for issue %i', repo.name, gh_issue.number)
 
         enhancement = Enhancement(gh_issue, log=self._logger)
-        self._logger.info(enhancement.type.value)
+        self._logger.debug(enhancement.type.value)
         if enhancement.type.value == EnhancementTypes.THEME.value \
                 or enhancement.type.value == EnhancementTypes.EPIC.value:  # not leaf in the tree
-            self._logger.info("search for epic children")
+            self._logger.debug("search for epic children")
             epic_child_issues = self._zenhub.get_epic_data(repo.id, gh_issue.number)
-            self._logger.info(epic_child_issues)
+            self._logger.debug(epic_child_issues)
             for issue in epic_child_issues['issues']:
                 if issue['repo_id'] == repo.id:
                     self._logger.debug("github api request, get issue %i", issue['issue_number'])
@@ -273,29 +282,25 @@ class Enhancement(Issue):
     def __init__(self, issue, log=None):
         if log:
             self._logger = log
-            log.info("Create enhancement for issue %i", issue.number)
+            log.debug("Create enhancement for issue %i", issue.number)
 
         self.issue = issue
         self.children = []
         self.type = Enhancement._get_enhancement_type(issue)
 
     def crawl(self):
-        self._logger.info("yield issue %i", self.issue.number)
+        self._logger.debug("yield issue %i", self.issue.number)
         yield self
         for child in self.children:
-            self._logger.info("crawl issue %i", child.issue.number)
+            self._logger.debug("crawl issue %i", child.issue.number)
             yield from child.crawl()
 
-
-
-
     @staticmethod
     def _get_enhancement_type(issue):
         enhancement_type = EnhancementTypes.TASK
         for label in issue.labels():
             if label.name in {item.value for item in EnhancementTypes}:
                 enhancement_type = EnhancementTypes(label.name)
-                print(label.name, enhancement_type.value)
                 break
 
         return enhancement_type
@@ -317,7 +322,7 @@ class RstRddReport(RddReport):
                  token=None):
 
         if not title:
-            build_text = f"(build {build})" if build else ''
+            build_text = f"(Build {build})" if build else ''
             title = f"Release Description Document " + build_text
         super().__init__(org,
                          title=title,
@@ -326,7 +331,7 @@ class RstRddReport(RddReport):
                          build=build,
                          token=token)
 
-        self._rst_doc = RstClothReferenceable()
+        self._rst_doc = RstClothReferenceable(line_width=120)
         self._rst_doc.title(title)
 
         if RstRddReport.ZENHUB_TOKEN not in os.environ.keys():
@@ -341,11 +346,15 @@ class RstRddReport(RddReport):
             "Getting change requests from %s/%s for build %s",
             self._org,
             RstRddReport.SWG_REPO_NAME,
-            self._build
+            self._target_build
         )
         swg_repo = self._gh.repository(self._org, RstRddReport.SWG_REPO_NAME)
 
-        change_requests = swg_repo.issues(state='closed', labels=','.join(['change-request', self._build]))
+        labels = ['change-request']
+        if self._build:
+            labels.append(self._build)
+
+        change_requests = swg_repo.issues(state='closed', labels=','.join(labels))
 
         columns = ["Issue", "Title", "Rationale"]
         data = []
@@ -370,11 +379,12 @@ class RstRddReport(RddReport):
         self._rst_doc._add(repo_info)
 
     def _get_theme_trees(self, repo):
-        labels = [self.THEME, self._build]
-        theme_issues = repo.issues(state='all', labels=','.join(labels), direction='asc')
+        labels = [self.THEME, self._target_build]
+        # Only want to see closed themes in the RDD, anything not closed should be in the deferrals
+        theme_issues = repo.issues(state='closed', labels=','.join(labels), direction='asc')
         theme_trees = []
         for theme_issue in theme_issues:
-            theme = EpicFactory(self._zenhub, self._logger).create_enhancement(repo, theme_issue, self._build)
+            theme = EpicFactory(self._zenhub, self._logger).create_enhancement(repo, theme_issue, self._target_build)
             theme_trees.append(theme)
         return theme_trees
 
@@ -389,7 +399,7 @@ class RstRddReport(RddReport):
         if issue_count:
             self._rst_doc.content("--------")
             self._rst_doc.newline()
-            self._rst_doc.h2(repo.name)
+            self._rst_doc.h2(repo.name.capitalize())
             self._add_repo_description(repo)
             planned_tickets = self._add_planned_updates(repo)
             self._add_other_updates(repo, issue_map, ignore_tickets=planned_tickets)
@@ -408,22 +418,25 @@ class RstRddReport(RddReport):
                     self._add_rst_repo_change_sub_section(repo, issue_type, issues, ignore_tickets=ignore_tickets)
 
     def _flush_theme_updates(self, theme_line, ticket_lines):
-        empty_suffix = "" if ticket_lines else " (no parent epic in this repository)"
-        theme_line = theme_line + empty_suffix
-        self._rst_doc.li(theme_line)
+        theme_line = theme_line
+        self._rst_doc.h4(theme_line)
         if ticket_lines:
             columns = ["Issue", "I&T", "Level", "Priority / Bug Severity"]
             self._rst_doc.table(
                 columns,
-                data=ticket_lines)
+                data=ticket_lines
+            )
+        else:
+            self._rst_doc.content("No requirements, significant enhancements, or bug fixes identified for this Build." +
+                                  " See theme for more details.")
 
         self._rst_doc.newline()
 
 
     @staticmethod
-    def _is_tested(issue):
+    def _testing_needed(issue):
         for label in issue.labels():
-            if label.name == RstRddReport.NOT_TESTED:
+            if label.name == RstRddReport.SKIP_TESTING:
                 return False
 
         return True
@@ -449,14 +462,19 @@ class RstRddReport(RddReport):
             for enhancement in theme_crawler:
                 issue = enhancement.issue
                 if not ignore_issue(issue.labels(), ignore_labels=RstRddReport.IGNORED_LABELS):
-                    self._logger.info("crawl theme tree %i", issue.number)
+                    self._logger.debug("crawl theme tree %i", issue.number)
                     self._rst_doc.hyperlink(f'{repo.name}#{issue.number}', issue.html_url)
-                    i_and_t = '|iandt|' if RstRddReport._is_tested(issue) else ''
+                    i_and_t = '|iandt|' if RstRddReport._testing_needed(issue) else ''
+                    priority = get_issue_priority(issue)
                     data.append([f'`{repo.name}#{issue.number}`_ {issue.title}'.replace('|', ''),
                                  i_and_t,
                                  enhancement.type.value,
-                                 get_issue_priority(issue)])
-                    planned_tickets.add(issue.number)
+                                 priority
+                                 ])
+                    if enhancement.type.value == 'requirement' and priority == 'unknown':
+                        self._log_missing_priority(repo.name, issue.number)
+
+                    planned_tickets.add(issue)
 
             self._flush_theme_updates(theme_head, data)
             done = True
@@ -477,22 +495,29 @@ class RstRddReport(RddReport):
         data = []
         for issue in issues:
             if issue.number not in ignore_tickets:
-                i_and_t = '|iandt|' if RstRddReport._is_tested(issue) else ''
+                i_and_t = '|iandt|' if RstRddReport._testing_needed(issue) else ''
                 self._rst_doc.hyperlink(f'{repo.name}#{issue.number}', issue.html_url)
+                priority = get_issue_priority(issue)
                 data.append([f'`{repo.name}#{issue.number}`_ {issue.title}'.replace('|', ''),
                              i_and_t,
-                             get_issue_priority(issue)])
-
+                             priority])
+                if type in {'bug', 'requirement'} and priority == 'unknown':
+                    self._log_missing_priority(repo.name, issue.number)
         if data:
             self._rst_doc.h4(type.capitalize() + 's')
             columns = ["Issue", "I&T", "Priority / Bug Severity"]
             self._rst_doc.table(
                 columns,
-                data=data)
+                data=data
+            )
+
+    def _log_missing_priority(self, repo_name, issue_number):
+        self._logger.warning('%s#%d misses priority', repo_name, issue_number)
+        self._logger.info('update at https://github.com/NASA-PDS/%s/issues/%d', repo_name, issue_number)
 
     def _add_software_changes(self, repos):
         self._logger.info("Add software changes")
-        self._rst_doc.deffered_directive('image',
+        self._rst_doc.deferred_directive('image',
                                          arg=f'https://nasa-pds.github.io/_static/images/noun_certified_18093.png',
                                          fields=[('alt', 'I&T'), ('width', '20')],
                                          reference='iandt')
@@ -528,10 +553,9 @@ class RstRddReport(RddReport):
         self._rst_doc.newline()
         self._rst_doc.hyperlink(
             f'Software Release Summary ({self._build})',
-            f'https://nasa-pds.github.io/releases/{self._build}/index.html'
+            f'https://nasa-pds.github.io/releases/{self._build[1:]}/index.html'
         )
 
-
     def _add_install_and_operation(self):
         self._logger.info("Add installation and operations")
         self._rst_doc.h1('Installation and Operation')
@@ -561,7 +585,6 @@ class RstRddReport(RddReport):
 
         self._rst_doc.newline()
 
-
     def _add_li(self, s):
         self._rst_doc.newline()
         self._rst_doc.li(s, wrap=False)
@@ -605,14 +628,17 @@ class RstRddReport(RddReport):
             'https://github.com/NASA-PDS/pds-doi-service/blob/master/docs/design/pds-doi-service-srd.md'
         )
 
-
     def _add_introduction(self):
+
         self._logger.info("Add introduction")
         self._rst_doc.content('This release of the PDS4 System is intended as an operational release of the system components to date.')
-        self._rst_doc.content(f'The original plan for this release can be found here: `Plan {self._build}`_')
-        self._rst_doc.newline()
-        self._rst_doc.content('The following sections can be found in this document:')
-        self._rst_doc.hyperlink(f'Plan {self._build}', f'https://nasa-pds.github.io/releases/{self._build[1:]}/plan.html')  # remove B prefix from the build code
+
+        if self._build:
+            self._rst_doc.content(f'The original plan for this release can be found here: `plan {self._build}`_')
+            self._rst_doc.newline()
+            self._rst_doc.content('The following sections can be found in this document:')
+            self._rst_doc.hyperlink(f'plan {self._target_build}', f'https://nasa-pds.github.io/releases/{self._build[1:]}/plan.html')  # remove B prefix from the build code
+
         self._rst_doc.newline()
         self._rst_doc.directive('toctree', fields=[('glob', ''), ('maxdepth', 3)], content='rdd.rst')
         self._rst_doc.newline()
@@ -632,7 +658,11 @@ class RstRddReport(RddReport):
         data = []
 
         repository = self._gh.repository(self._org, IM_REPO)
-        labels = ['pending-scr', self._build]
+
+        labels = ['pending-scr']
+        if self._target_build:
+            labels.append(self._target_build)
+
         for issue in repository.issues(state='closed', labels=','.join(labels), direction='asc', since=self._start_time):
             self._rst_doc.hyperlink(f'{IM_REPO}#{issue.number}', issue.html_url)
             data.append([f'`{IM_REPO}#{issue.number}`_'.replace('|', ''), issue.title])
