@@ -1,12 +1,13 @@
 import os
 import logging
-from rstcloth import RstCloth
+import rstcloth
 
 logger = logging.getLogger(__name__)
 
 
-def _indent(content, indent):
+def _indent_ok_for_table(content, indent):
     """
+
     :param content:
     :param indent:
     :return:
@@ -17,19 +18,27 @@ def _indent(content, indent):
         indent = " " * indent
         if isinstance(content, list):
             return ["".join([indent, line]) for line in content]
+        elif '\n' in content:
+            content_lines = content.split('\n')
+            return f"\n{indent}".join(content_lines)
         else:
             return "".join([indent, content])
 
+# hacky rewirting of the function used in the rstpackage
+# should do a pull request eventually
+rstcloth.rstcloth._indent = _indent_ok_for_table
+_indent = _indent_ok_for_table
 
-class RstClothReferenceable(RstCloth):
-    def __init__(self, line_width=72):
+
+class RstClothReferenceable(rstcloth.RstCloth):
+    def __init__(self, line_width=160):
         super().__init__(line_width=line_width)
-        self._deffered_directives = []
+        self._deferred_directives = []
 
     def hyperlink(self, ref, url):
-        self._deffered_directives.append(f".. _{ref}: {url}")
+        self._deferred_directives.append(f".. _{ref}: {url}")
 
-    def deffered_directive(self, name, arg=None, fields=None, content=None, indent=0, wrap=True, reference=None):
+    def deferred_directive(self, name, arg=None, fields=None, content=None, indent=0, wrap=True, reference=None):
         """
         :param name: the directive itself to use
         :param arg: the argument to pass into the directive
@@ -62,7 +71,7 @@ class RstClothReferenceable(RstCloth):
             else:
                 o.append(_indent(content, 3))
 
-        self._deffered_directives.extend(_indent(o, indent))
+        self._deferred_directives.extend(_indent(o, indent))
 
     def write(self, filename):
         """
@@ -79,5 +88,6 @@ class RstClothReferenceable(RstCloth):
         with open(filename, "w") as f:
             f.write("\n".join(self._data))
             f.write("\n")
-            f.write("\n".join(self._deffered_directives))
-            f.write("\n")
\ No newline at end of file
+            f.write("\n".join(self._deferred_directives))
+            f.write("\n")
+
