@@ -4,12 +4,9 @@ import sys
 
 from github3 import login
 
-# Quiet github3 logging
-logger = logging.getLogger('github3')
-logger.setLevel(level=logging.WARNING)
 
-logging.basicConfig(level=logging.INFO)
-logger = logging.getLogger(__name__)
+_logger = logging.getLogger(__name__)
+
 
 class GithubConnection():
 
@@ -20,7 +17,7 @@ class GithubConnection():
         if not cls.gh:
             token = token or os.environ.get('GITHUB_TOKEN')
             if not token:
-                logger.error(f'Github token must be provided or set as environment variable (GITHUB_TOKEN).')
+                _logger.error('Github token must be provided or set as environment variable (GITHUB_TOKEN).')
                 sys.exit(1)
 
             cls.gh = login(token=token)
